# bln-python-client

Python client for the biglocalnews.org API

## Installation

Use `pip` or `pipenv` to install the Python library and command-line interface.

```bash
pipenv install bln
```

## Documentation

```{toctree}
:glob:
:maxdepth: 1

gettingstarted
pandas
contributing
releasing
reference
```

## Links

* Documentation: [bln-python-client.readthedocs.io](https://bln-python-client.readthedocs.io/)
* Repository: [github.com/biglocalnews/bln-python-client](https://github.com/biglocalnews/bln-python-client)
* Packaging: [pypi.org/project/bln](https://pypi.org/project/bln/)

## About

The project is sponsored by [Big Local News](https://biglocalnews.org/#/about), a program at Stanford University that collects data for impactful journalism. The code is maintained by Stanford Lecturer [Serdar Tumgoren](https://comm.stanford.edu/faculty-tumgoren/) and [Ben Welsh](https://palewi.re/who-is-ben-welsh/), a visiting data journalist from the Los Angeles Times.
